import click
from data.main import connect
import os
from pathlib import Path
import seaborn as sns
import matplotlib.pyplot as plt
import numpy as np
import pandas as pd

out_path = Path(os.getenv('DATA_MINING_DOC_DIR')) / 'figures'

@click.command('plot:bias-hist')
def hist():
    filename = "bias_hist.png"

    DB = connect()
    data = DB.sql("""
        SELECT
            b.ordinal
            ,count(1) as stories
        FROM stories s
        JOIN publisher_bias pb
        ON pb.publisher_id = s.publisher_id
        JOIN bias_ratings b
        ON b.id = pb.bias_id
        GROUP BY
            b.ordinal
    """).df()
    DB.close()

    ax = sns.barplot(x=data['ordinal'], y=data['stories'], color='tab:blue')
    ticklabels = ['left', 'left-center', 'center', 'right-center', 'right']
    ax.set(title="count of stories per bias rating", xlabel="bias rating", xticklabels=ticklabels)
    plt.tight_layout()
    plt.savefig(out_path / filename)
    print(f"saved: {filename}")
@click.command('plot:bias-publisher-hist')
def publisher_hist():
    filename = "bias_publisher_hist.png"

    DB = connect()
    data = DB.sql("""
        SELECT
            b.ordinal
            ,count(1) as publishers
        FROM publisher_bias pb
        JOIN bias_ratings b
        ON b.id = pb.bias_id
        GROUP BY
            b.ordinal
    """).df()
    DB.close()

    ax = sns.barplot(x=data['ordinal'], y=data['publishers'], color='tab:blue')
    ticklabels = ['left', 'left-center', 'center', 'right-center', 'right']
    ax.set(title="count of publishers per bias rating", xlabel="bias rating", xticklabels=ticklabels)
    plt.tight_layout()
    plt.savefig(out_path / filename)
    plt.close()
    print(f"saved: {filename}")
