import click
from data.main import connect
import os
import seaborn as sns
import matplotlib.pyplot as plt
from pathlib import Path

out_dir = Path(os.getenv('DATA_MINING_DOC_DIR')) / 'figures'

@click.command('plot:pca-with-classes')
def pca_with_classes():
    filename = "pca_with_classes.png"

    DB = connect()
    data = DB.query(f"""
        SELECT
            p.tld
            ,b.bias
            ,c.first
            ,c.second
            ,round(cast(b.agree as float) / (b.agree + b.disagree), 2) ratio
        FROM top.publishers p
        JOIN top.publisher_bias pb
        ON p.id = pb.publisher_id
        JOIN bias_ratings b
        ON b.id = pb.bias_id
        JOIN top.publisher_pca_normalized c
        ON c.publisher_id = p.id
    """).df()
    DB.close()
    ax = sns.scatterplot(x=data['first'], y=data['second'], hue=data['bias'], s=100)
    ax.set(title="pca components vs. bias labels", xlabel="first pca component", ylabel="second pca component")
    plt.savefig(out_dir / filename)
    print(f"saved: {filename}")
